=======
History
=======


1.1.0 - 2016-02-04
==================

* Add a ``ModelInstance`` parameter type to automatically retrieve model
  instances by their primary key


1.0.0 – 2015-09-14
==================

* Support for command groups
* Added a ``pass_verbosity`` decorator
* Improved test suite


0.1.1 – 2015-09-11
==================

* Django 1.4, 1.5, 1.6, 1.7 and 1.8 compatibility
* Python 2.7 and 3.4 compatibility
* 100% coverage test suite


0.1.0 – 2015-09-10
==================

* Initial release
